avoid function parameters names 'list' as this seems to give troubles with

* valid.c xmlregexp.c include/libxml/valid.h
  include/libxml/xmlregexp.h: avoid function parameters names 'list'
  as this seems to give troubles with VC6 and stl as reported by
  Samuel Diaz Garcia.
Daniel
diff --git a/xmlregexp.c b/xmlregexp.c
index dea0977..fe02822 100644
--- a/xmlregexp.c
+++ b/xmlregexp.c
@@ -6455,7 +6455,7 @@
  * xmlExpGetLanguage:
  * @ctxt: the expression context
  * @exp: the expression
  * @list: where to store the tokens
  * @len: the allocated lenght of @list
  *
  * Find all the strings used in @exp and store them in @list
@@ -6465,10 +6465,10 @@
  */
 int
 xmlExpGetLanguage(xmlExpCtxtPtr ctxt, xmlExpNodePtr exp, 
-                  const xmlChar**list, int len) {
-    if ((ctxt == NULL) || (exp == NULL) || (list == NULL) || (len <= 0))
+                  const xmlChar**langList, int len) {
+    if ((ctxt == NULL) || (exp == NULL) || (langList == NULL) || (len <= 0))
         return(-1);
-    return(xmlExpGetLanguageInt(ctxt, exp, list, len, 0));
+    return(xmlExpGetLanguageInt(ctxt, exp, langList, len, 0));
 }
 
 static int
@@ -6521,7 +6521,7 @@
  * xmlExpGetStart:
  * @ctxt: the expression context
  * @exp: the expression
  * @list: where to store the tokens
  * @len: the allocated lenght of @list
  *
  * Find all the strings that appears at the start of the languages
@@ -6533,10 +6533,10 @@
  */
 int
 xmlExpGetStart(xmlExpCtxtPtr ctxt, xmlExpNodePtr exp, 
-               const xmlChar**list, int len) {
-    if ((ctxt == NULL) || (exp == NULL) || (list == NULL) || (len <= 0))
+               const xmlChar**tokList, int len) {
+    if ((ctxt == NULL) || (exp == NULL) || (tokList == NULL) || (len <= 0))
         return(-1);
-    return(xmlExpGetStartInt(ctxt, exp, list, len, 0));
+    return(xmlExpGetStartInt(ctxt, exp, tokList, len, 0));
 }
 
 /**
@@ -6455,7 +6455,7 @@
  * @ctxt: the expression context
  * @exp: the expression
- * @list: where to store the tokens
+ * @langList: where to store the tokens
  * @len: the allocated lenght of @list
  *
@@ -6521,7 +6521,7 @@
  * @ctxt: the expression context
  * @exp: the expression
- * @list: where to store the tokens
+ * @tokList: where to store the tokens
  * @len: the allocated lenght of @list
  *